use warnings;
use strict;
use Test::More tests => 30;
use Test::Exception;

use Errno; sub E { no strict 'refs'; local $!=&{"Errno::$_[0]"}; }

use POWER::Utils::IO;

# Nonblock

throws_ok { Nonblock()                      } qr/usage: Nonblock/;
throws_ok { Nonblock(1,2)                   } qr/usage: Nonblock/;

throws_ok { Nonblock(undef)                 } qr/isn't FILEHANDLE/;
throws_ok { Nonblock('STDIN')               } qr/isn't FILEHANDLE/;
throws_ok { Nonblock(0)                     } qr/isn't FILEHANDLE/;
throws_ok { Nonblock(*STDIN)                } qr/isn't FILEHANDLE/;
throws_ok { Nonblock(\*QWE); \*QWE;         } qr/isn't FILEHANDLE/;

lives_ok  { Nonblock(\*STDIN)               };

# Accept

throws_ok { Accept()                        } qr/usage: Accept/;
throws_ok { Accept(undef)                   } qr/usage: Accept/;
throws_ok { Accept(1,2,3,4)                 } qr/usage: Accept/;

throws_ok { Accept(undef, sub{})            } qr/isn't open FILEHANDLE/;

throws_ok { Accept(\*STDIN, sub{})          } qr/accept: ${\E 'ENOTSOCK'}/;

# Sysread

throws_ok { Sysread()                       } qr/usage: Sysread/;
throws_ok { Sysread(undef)                  } qr/usage: Sysread/;
throws_ok { Sysread(1,2,3)                  } qr/usage: Sysread/;

throws_ok { Sysread(undef, my $buf)         } qr/isn't open/;

throws_ok { Sysread(\*STDOUT, my $buf)      } qr/BUFFER undefined/;

throws_ok { Sysread(\*STDOUT, my $buf=q{})  } qr/sysread: ${\E 'EBADF'}/;

lives_ok  { Sysread(\*STDIN, my $buf=q{})   };

# Syswrite

throws_ok { Syswrite()                      } qr/usage: Syswrite/;
throws_ok { Syswrite(undef)                 } qr/usage: Syswrite/;
throws_ok { Syswrite(1,2,3,4)               } qr/usage: Syswrite/;

throws_ok { Syswrite(undef, my $buf)        } qr/isn't open/;

throws_ok { Syswrite(\*STDERR, my $buf)     } qr/BUFFER undefined/;
throws_ok { Syswrite(\*STDERR, my $buf, 0)  } qr/BUFFER undefined/;

throws_ok { Syswrite(\*STDERR, my $buf=q{}, undef)  } qr/POSITION undefined/;
throws_ok { Syswrite(\*STDERR, my $buf=q{}, -1)     } qr/ < 0/;
throws_ok { Syswrite(\*STDERR, my $buf=q{}, 1)      } qr/>= BUFFER length/;

throws_ok { Syswrite(\*DATA, my $buf=q{.}) } qr/syswrite: ${\E 'EBADF'}/;

__DATA__
